@@ -107,6 +107,7 @@ end
 
 def do_libs(libs, strip = 'lib/')
   libs.each do |lf|
+    next if File.directory? lf
     olf = File.join(InstallOptions.site_dir, lf.sub(/^#{strip}/, ''))
     op = File.dirname(olf)
     if $haveftools
@@ -414,7 +415,7 @@ FileUtils.cd File.dirname(__FILE__) do
   rdoc  = glob(%w{bin/* lib/**/*.rb README* }).reject { |e| e=~ /\.(bat|cmd)$/ }
   ri    = glob(%w{bin/*.rb lib/**/*.rb}).reject { |e| e=~ /\.(bat|cmd)$/ }
   man   = glob(%w{man/man[0-9]/*})
-  libs  = glob(%w{lib/**/*.rb lib/**/*.erb lib/**/*.py lib/puppet/util/command_line/*})
+  libs  = glob(%w{lib/**/*})
 
   check_prereqs
   prepare_installation
