@@ -1,6 +1,8 @@
 require 'puppet/version'
 
 # see the bottom of the file for further inclusions
+# Also see the new Vendor support - towards the end
+#
 require 'facter'
 require 'puppet/error'
 require 'puppet/util'
@@ -25,6 +27,8 @@ require 'puppet/external/pson/pure'
 #
 # @api public
 module Puppet
+  require 'puppet/file_system'
+
   class << self
     include Puppet::Util
     attr_reader :features
@@ -153,6 +157,15 @@ module Puppet
   def self.newtype(name, options = {}, &block)
     Puppet::Type.newtype(name, options, &block)
   end
+
+  # Load vendored (setup paths, and load what is needed upfront).
+  # See the Vendor class for how to add additional vendored gems/code
+  require "puppet/vendor"
+  Puppet::Vendor.load_vendored
+
+  # Set default for YAML.load to unsafe so we don't affect programs
+  # requiring puppet -- in puppet we will call safe explicitly
+  SafeYAML::OPTIONS[:default_mode] = :unsafe
 end
 
 # This feels weird to me; I would really like for us to get to a state where there is never a "require" statement
