@@ -157,7 +157,7 @@ with '--genconfig'.
   option requires LDAP support at this point.
 
 * --ping:
-  Do a ICMP echo against the target host. Skip hosts that don't respond
+  Do an ICMP echo against the target host. Skip hosts that don't respond
   to ping.
 
 
@@ -240,7 +240,7 @@ Copyright (c) 2011 Puppet Labs, LLC Licensed under the Apache 2.0 License
 
   def run_for_host(host)
     if options[:ping]
-      out = %x{ping -c 1 #{host}}
+      %x{ping -c 1 #{host}}
       unless $CHILD_STATUS == 0
         $stderr.print "Could not contact #{host}\n"
         exit($CHILD_STATUS)
