@@ -29,16 +29,9 @@ module Puppet::Configurer::FactHandler
 
   def facts_for_uploading
     facts = find_facts
-    #format = facts.class.default_format
 
-    if facts.support_format?(:b64_zlib_yaml)
-      format = :b64_zlib_yaml
-    else
-      format = :yaml
-    end
+    text = facts.render(:pson)
 
-    text = facts.render(format)
-
-    {:facts_format => format, :facts => CGI.escape(text)}
+    {:facts_format => :pson, :facts => CGI.escape(text)}
   end
 end
