@@ -35,13 +35,13 @@ module DOT
     'fontcolor',   # default: black; type face color
     'fontname',    # default: Times-Roman; font family
     'fontsize',    # default: 14; point size of label
-    'group',       # name of nodes group
+    'group',       # name of node's group
     'height',      # default: .5; height in inches
     'label',       # default: node name; any string
     'layer',       # default: overlay range; all, id or id:id
-    'orientation', # dafault: 0.0; node rotation angle
+    'orientation', # default: 0.0; node rotation angle
     'peripheries', # shape-dependent number of node boundaries
-    'regular',     # default:  false; force polygon to be regular
+    'regular',     # default: false; force polygon to be regular
     'shape',       # default: ellipse; node shape; see Section 2.1 and Appendix E
     'shapefile',   # external EPSF or SVG custom shape file
     'sides',       # default: 4; number of sides for shape=polygon
