@@ -10,20 +10,23 @@ Puppet.features.add(:syslog, :libs => ["syslog"])
 # We can use POSIX user functions
 Puppet.features.add(:posix) do
   require 'etc'
-  Etc.getpwuid(0) != nil && Puppet.features.syslog?
+  !Etc.getpwuid(0).nil? && Puppet.features.syslog?
 end
 
 # We can use Microsoft Windows functions
 Puppet.features.add(:microsoft_windows) do
   begin
+    # ruby
+    require 'Win32API'          # case matters in this require!
+    require 'win32ole'
+    require 'win32/registry'
+    # gems
     require 'sys/admin'
     require 'win32/process'
     require 'win32/dir'
     require 'win32/service'
-    require 'win32ole'
     require 'win32/api'
     require 'win32/taskscheduler'
-    require 'puppet/util/windows/security'
     true
   rescue LoadError => err
     warn "Cannot run on Microsoft Windows without the sys-admin, win32-process, win32-dir, win32-service and win32-taskscheduler gems: #{err}" unless Puppet.features.posix?
@@ -44,9 +47,6 @@ Puppet.features.add(:libshadow, :libs => ["shadow"])
 # We're running as root.
 Puppet.features.add(:root) { require 'puppet/util/suidmanager'; Puppet::Util::SUIDManager.root? }
 
-# We've got mongrel available
-Puppet.features.add(:mongrel, :libs => %w{rubygems mongrel puppet/network/http_server/mongrel})
-
 # We have lcs diff
 Puppet.features.add :diff, :libs => %w{diff/lcs diff/lcs/hunk}
 
@@ -65,3 +65,24 @@ Puppet.features.add(:couchdb, :libs => ["couchrest"])
 
 # We have sqlite
 Puppet.features.add(:sqlite, :libs => ["sqlite3"])
+
+# We have Hiera
+Puppet.features.add(:hiera, :libs => ["hiera"])
+
+Puppet.features.add(:minitar, :libs => ["archive/tar/minitar"])
+
+# We can manage symlinks
+Puppet.features.add(:manages_symlinks) do
+  if ! Puppet::Util::Platform.windows?
+    true
+  else
+    begin
+      require 'Win32API'
+      Win32API.new('kernel32', 'CreateSymbolicLink', 'SSL', 'B')
+      true
+    rescue LoadError => err
+      Puppet.debug("CreateSymbolicLink is not available")
+      false
+    end
+  end
+end
