@@ -30,7 +30,7 @@ module Puppet::Forge::Errors
     #
     # @return [String] the multiline version of the error message
     def multiline
-      message = <<-EOS.chomp
+      <<-EOS.chomp
 Could not connect via HTTPS to #{@uri}
   Unable to verify the SSL certificate
     The certificate may not be signed by a valid CA
@@ -57,7 +57,7 @@ Could not connect via HTTPS to #{@uri}
     #
     # @return [String] the multiline version of the error message
     def multiline
-      message = <<-EOS.chomp
+      <<-EOS.chomp
 Could not connect to #{@uri}
   There was a network communications problem
     The error we caught said '#{@detail}'
@@ -78,7 +78,7 @@ Could not connect to #{@uri}
       @input   = options[:input]
       @message = options[:message]
       response = options[:response]
-      @response = "#{response.code} #{response.message}"
+      @response = "#{response.code} #{response.message.strip}"
 
       message = "Could not execute operation for '#{@input}'. Detail: "
       message << @message << " / " if @message
