@@ -55,7 +55,8 @@ class Puppet::Indirector::REST < Puppet::Indirector::Terminus
   end
 
   def network(request)
-    Puppet::Network::HTTP::Connection.new(request.server || self.class.server, request.port || self.class.port)
+    Puppet::Network::HttpPool.http_instance(request.server || self.class.server,
+                                            request.port || self.class.port)
   end
 
   def http_get(request, path, headers = nil, *args)
