@@ -20,6 +20,7 @@ class Puppet::Module
     "files" => "files",
     "templates" => "templates",
     "plugins" => "lib",
+    "pluginfacts" => "facts.d",
   }
 
   # Find and return the +module+ that +path+ belongs to. If +path+ is
@@ -53,10 +54,14 @@ class Puppet::Module
   def has_metadata?
     return false unless metadata_file
 
-    return false unless FileTest.exist?(metadata_file)
-
-    metadata = PSON.parse File.read(metadata_file)
+    return false unless Puppet::FileSystem::File.exist?(metadata_file)
 
+    begin
+      metadata =  PSON.parse(File.read(metadata_file))
+    rescue PSON::PSONError => e
+      Puppet.debug("#{name} has an invalid and unparsable metadata.json file.  The parse error: #{e.message}")
+      return false
+    end
 
     return metadata.is_a?(Hash) && !metadata.keys.empty?
   end
@@ -66,7 +71,7 @@ class Puppet::Module
     # we have files of a given type.
     define_method(type +'?') do
       type_subpath = subpath(location)
-      unless FileTest.exist?(type_subpath)
+      unless Puppet::FileSystem::File.exist?(type_subpath)
         Puppet.debug("No #{type} found in subpath '#{type_subpath}' " +
                          "(file / directory does not exist)")
         return false
@@ -89,7 +94,7 @@ class Puppet::Module
         full_path = subpath(location)
       end
 
-      return nil unless FileTest.exist?(full_path)
+      return nil unless Puppet::FileSystem::File.exist?(full_path)
       return full_path
     end
 
@@ -148,7 +153,7 @@ class Puppet::Module
   end
 
   def all_manifests
-    return [] unless File.exists?(manifests)
+    return [] unless Puppet::FileSystem::File.exist?(manifests)
 
     Dir.glob(File.join(manifests, '**', '*.{rb,pp}'))
   end
@@ -169,6 +174,14 @@ class Puppet::Module
     subpath("lib")
   end
 
+  def plugin_fact_directory
+    subpath("facts.d")
+  end
+
+  def has_external_facts?
+    File.directory?(plugin_fact_directory)
+  end
+
   def supports(name, version = nil)
     @supports ||= []
     @supports << [name, version]
