@@ -10,7 +10,6 @@ require 'puppet/ssl/configuration'
 class Puppet::Network::HTTP::WEBrick
   def initialize
     @listening = false
-    @mutex = Mutex.new
   end
 
   def listen(address, port)
@@ -25,34 +24,31 @@ class Puppet::Network::HTTP::WEBrick
 
     @server.mount('/', Puppet::Network::HTTP::WEBrickREST, :this_value_is_apparently_necessary_but_unused)
 
-    @mutex.synchronize do
-      raise "WEBrick server is already listening" if @listening
-      @listening = true
-      @thread = Thread.new {
-        @server.start { |sock|
-          raise "Client disconnected before connection could be established" unless IO.select([sock],nil,nil,6.2)
-          sock.accept
-          @server.run(sock)
-        }
-      }
-      sleep 0.1 until @server.status == :Running
+    raise "WEBrick server is already listening" if @listening
+    @listening = true
+    @thread = Thread.new do
+      @server.start do |sock|
+        timeout = 10.0
+        if ! IO.select([sock],nil,nil,timeout)
+          raise "Client did not send data within %.1f seconds of connecting" % timeout
+        end
+        sock.accept
+        @server.run(sock)
+      end
     end
+    sleep 0.1 until @server.status == :Running
   end
 
   def unlisten
-    @mutex.synchronize do
-      raise "WEBrick server is not listening" unless @listening
-      @server.shutdown
-      wait_for_shutdown
-      @server = nil
-      @listening = false
-    end
+    raise "WEBrick server is not listening" unless @listening
+    @server.shutdown
+    wait_for_shutdown
+    @server = nil
+    @listening = false
   end
 
   def listening?
-    @mutex.synchronize do
-      @listening
-    end
+    @listening
   end
 
   def wait_for_shutdown
