@@ -19,23 +19,6 @@ end
 # The 'environment' global variable represents the current environment that's
 # being used in the compiler.
 #
-# ### `$known_resource_types`
-#
-# The 'known_resource_types' global variable represents a singleton instance
-# of the Puppet::Resource::TypeCollection class. The variable is discarded
-# and regenerated if it is accessed by an environment that doesn't match the
-# environment of the 'known_resource_types'
-#
-# This behavior of discarding the known_resource_types every time the
-# environment changes is not ideal. In the best case this can cause valid data
-# to be discarded and reloaded. If Puppet is being used with numerous
-# environments then this penalty will be repeatedly incurred.
-#
-# In the worst case (#15106) demonstrates that if a different environment is
-# accessed during catalog compilation, for whatever reason, the
-# known_resource_types can be discarded which loses information that cannot
-# be recovered and can cause a catalog compilation to completely fail.
-#
 # ## The root environment
 #
 # In addition to normal environments that are defined by the user,there is a
@@ -204,20 +187,11 @@ class Puppet::Node::Environment
   # @api public
   # @return [Puppet::Resource::TypeCollection] The current global TypeCollection
   def known_resource_types
-    # This makes use of short circuit evaluation to get the right thread-safe
-    # per environment semantics with an efficient most common cases; we almost
-    # always just return our thread's known-resource types.  Only at the start
-    # of a compilation (after our thread var has been set to nil) or when the
-    # environment has changed do we delve deeper.
-    $known_resource_types = nil if $known_resource_types && $known_resource_types.environment != self
-    $known_resource_types ||=
-      if @known_resource_types.nil? or @known_resource_types.require_reparse?
-        @known_resource_types = Puppet::Resource::TypeCollection.new(self)
-        @known_resource_types.import_ast(perform_initial_import, '')
-        @known_resource_types
-      else
-        @known_resource_types
-      end
+    if @known_resource_types.nil?
+      @known_resource_types = Puppet::Resource::TypeCollection.new(self)
+      @known_resource_types.import_ast(perform_initial_import(), '')
+    end
+    @known_resource_types
   end
 
   # Yields each modules' plugin directory if the plugin directory (modulename/lib)
@@ -393,6 +367,13 @@ class Puppet::Node::Environment
     deps
   end
 
+
+  def check_for_reparse
+    if @known_resource_types && @known_resource_types.require_reparse?
+      @known_resource_types = nil
+    end
+  end
+
   # @return [String] The stringified value of the `name` instance variable
   # @api public
   def to_s
@@ -465,7 +446,7 @@ class Puppet::Node::Environment
     end
     parser.parse
   rescue => detail
-    known_resource_types.parse_failed = true
+    @known_resource_types.parse_failed = true
 
     msg = "Could not parse for environment #{self}: #{detail}"
     error = Puppet::Error.new(msg)
