@@ -84,16 +84,33 @@ class Puppet::Node::Facts
     new_facts
   end
 
-  def to_pson(*args)
+  def to_data_hash
     result = {
       'name' => name,
       'values' => strip_internal,
     }
 
-    result['timestamp'] = timestamp if timestamp
-    result['expiration'] = expiration if expiration
+    if timestamp
+      if timestamp.is_a? Time
+        result['timestamp'] = timestamp.iso8601(9)
+      else
+        result['timestamp'] = timestamp
+      end
+    end
 
-    result.to_pson(*args)
+    if expiration
+      if expiration.is_a? Time
+        result['expiration'] = expiration.iso8601(9)
+      else
+        result['expiration'] = expiration
+      end
+    end
+
+    result
+  end
+
+  def to_pson(*args)
+    to_data_hash.to_pson(*args)
   end
 
   # Add internal data to the facts for storage.
@@ -109,8 +126,6 @@ class Puppet::Node::Facts
     self.values['_timestamp']
   end
 
-  private
-
   # Strip out that internal data.
   def strip_internal
     newvals = values.dup
@@ -118,6 +133,8 @@ class Puppet::Node::Facts
     newvals
   end
 
+  private
+
   def sanitize_fact(fact)
     if fact.is_a? Hash then
       ret = {}
