@@ -1,3 +1,6 @@
+# @api public
+module Puppet::Parser; end
+
 require 'puppet/parser/parser'
 require 'puppet/parser/compiler'
 require 'puppet/resource/type_collection'
