@@ -2,6 +2,7 @@ Puppet::Type.type(:file).provide :windows do
   desc "Uses Microsoft Windows functionality to manage file ownership and permissions."
 
   confine :operatingsystem => :windows
+  has_feature :manages_symlinks if Puppet.features.manages_symlinks?
 
   include Puppet::Util::Warnings
 
@@ -35,33 +36,37 @@ Puppet::Type.type(:file).provide :windows do
   alias :name2uid :name2id
 
   def owner
-    return :absent unless resource.exist?
+    return :absent unless resource.stat
     get_owner(resource[:path])
   end
 
   def owner=(should)
     begin
-      set_owner(should, resource[:path])
+      path = resource[:links] == :manage ? file.path.to_s : file.readlink
+
+      set_owner(should, path)
     rescue => detail
       raise Puppet::Error, "Failed to set owner to '#{should}': #{detail}"
     end
   end
 
   def group
-    return :absent unless resource.exist?
+    return :absent unless resource.stat
     get_group(resource[:path])
   end
 
   def group=(should)
     begin
-      set_group(should, resource[:path])
+      path = resource[:links] == :manage ? file.path.to_s : file.readlink
+
+      set_group(should, path)
     rescue => detail
       raise Puppet::Error, "Failed to set group to '#{should}': #{detail}"
     end
   end
 
   def mode
-    if resource.exist?
+    if resource.stat
       mode = get_mode(resource[:path])
       mode ? mode.to_s(8) : :absent
     else
@@ -85,4 +90,10 @@ Puppet::Type.type(:file).provide :windows do
       resource.fail("Can only manage owner, group, and mode on filesystems that support Windows ACLs, such as NTFS")
     end
   end
+
+  attr_reader :file
+  private
+  def file
+    @file ||= Puppet::FileSystem::File.new(resource[:path])
+  end
 end
