@@ -1,7 +1,7 @@
 require 'puppet/provider/parsedfile'
 
 hosts = nil
-case Facter.value(:operatingsystem)
+case Facter.value(:osfamily)
 when "Solaris"; hosts = "/etc/inet/hosts"
 when "windows"
   require 'win32/resolv'
