@@ -17,7 +17,7 @@ Puppet::Type.type(:macauthorization).provide :macauthorization, :parent => Puppe
   # This should be confined based on macosx_productversion
   # but puppet resource doesn't make the facts available and
   # that interface is heavily used with this provider.
-  if FileTest.exists?("/usr/bin/sw_vers")
+  if Puppet::FileSystem::File.exist?("/usr/bin/sw_vers")
     product_version = sw_vers "-productVersion"
 
     confine :true => unless /^10\.[0-4]/.match(product_version)
