@@ -5,10 +5,15 @@ require 'puppet'
 module Puppet::Provider::Mount
   # This only works when the mount point is synced to the fstab.
   def mount
-    # Manually pass the mount options in, since some OSes *cough*OS X*cough* don't
-    # read from /etc/fstab but still want to use this type.
     args = []
-    args << "-o" << self.options if self.options and self.options != :absent
+
+    # In general we do not have to pass mountoptions because we always
+    # flush /etc/fstab before attempting to mount. But old code suggests
+    # that MacOS always needs the mount options to be explicitly passed to
+    # the mount command
+    if Facter.value(:kernel) == 'Darwin'
+      args << "-o" << self.options if self.options and self.options != :absent
+    end
     args << resource[:name]
 
     mountcmd(*args)
