@@ -84,7 +84,7 @@ Puppet::Type.type(:package).provide :apt, :parent => :dpkg, :source => :dpkg do
   # preseeds answers to dpkg-set-selection from the "responsefile"
   #
   def run_preseed
-    if response = @resource[:responsefile] and FileTest.exist?(response)
+    if response = @resource[:responsefile] and Puppet::FileSystem::File.exist?(response)
       self.info("Preseeding #{response} to debconf-set-selections")
 
       preseed response
