@@ -48,7 +48,7 @@ Puppet::Type.type(:package).provide :pip,
   # it is not installed or `pip` itself is not available.
   def query
     self.class.instances.each do |provider_pip|
-      return provider_pip.properties if @resource[:name] == provider_pip.name
+      return provider_pip.properties if @resource[:name].downcase == provider_pip.name.downcase
     end
     return nil
   end
