@@ -7,9 +7,11 @@ Puppet::Type.type(:service).provide :bsd, :parent => :init do
 
   EOT
 
-  confine :operatingsystem => [:freebsd, :netbsd, :openbsd]
+  confine :operatingsystem => [:freebsd, :netbsd, :openbsd, :dragonfly]
 
-  @@rcconf_dir = '/etc/rc.conf.d'
+  def rcconf_dir
+    '/etc/rc.conf.d'
+  end
 
   def self.defpath
     superclass.defpath
@@ -17,14 +19,14 @@ Puppet::Type.type(:service).provide :bsd, :parent => :init do
 
   # remove service file from rc.conf.d to disable it
   def disable
-    rcfile = File.join(@@rcconf_dir, @model[:name])
-    File.delete(rcfile) if File.exists?(rcfile)
+    rcfile = File.join(rcconf_dir, @model[:name])
+    File.delete(rcfile) if Puppet::FileSystem::File.exist?(rcfile)
   end
 
   # if the service file exists in rc.conf.d then it's already enabled
   def enabled?
-    rcfile = File.join(@@rcconf_dir, @model[:name])
-    return :true if File.exists?(rcfile)
+    rcfile = File.join(rcconf_dir, @model[:name])
+    return :true if Puppet::FileSystem::File.exist?(rcfile)
 
     :false
   end
@@ -32,8 +34,8 @@ Puppet::Type.type(:service).provide :bsd, :parent => :init do
   # enable service by creating a service file under rc.conf.d with the
   # proper contents
   def enable
-    Dir.mkdir(@@rcconf_dir) if not File.exists?(@@rcconf_dir)
-    rcfile = File.join(@@rcconf_dir, @model[:name])
+    Dir.mkdir(rcconf_dir) if not Puppet::FileSystem::File.exist?(rcconf_dir)
+    rcfile = File.join(rcconf_dir, @model[:name])
     open(rcfile, 'w') { |f| f << "%s_enable=\"YES\"\n" % @model[:name] }
   end
 
