@@ -25,15 +25,8 @@ Puppet::Type.type(:service).provide :upstart, :parent => :debian do
   # http://www.linuxplanet.com/linuxplanet/tutorials/7033/2/
   has_feature :enableable
 
-  # 'wait-for-state' is excluded from instances here because it takes
-  # parameters that have unclear meaning. It looks like 'wait-for-state' is
-  # mainly used internally for other upstart services as a 'sleep until something happens'
-  # (http://lists.debian.org/debian-devel/2012/02/msg01139.html). There is an open launchpad bug
-  # (https://bugs.launchpad.net/ubuntu/+source/upstart/+bug/962047) that may
-  # eventually explain how to use this service or perhaps why it should remain
-  # excluded. When that bug is adddressed this should be reexamined.
   def self.instances
-    self.get_services(['wait-for-state'])
+    self.get_services(self.excludes) # Take exclude list from init provider
   end
 
   def self.get_services(exclude=[])
@@ -78,7 +71,7 @@ Puppet::Type.type(:service).provide :upstart, :parent => :debian do
       paths.each do |path|
         service_name = name.match(/^(\S+)/)[1]
         fqname = File.join(path, service_name + suffix)
-        if File.exists?(fqname)
+        if Puppet::FileSystem::File.exist?(fqname)
           return fqname
         end
 
@@ -155,7 +148,7 @@ Puppet::Type.type(:service).provide :upstart, :parent => :debian do
 
 private
   def is_upstart?(script = initscript)
-    File.exists?(script) && script.match(/\/etc\/init\/\S+\.conf/)
+    Puppet::FileSystem::File.exist?(script) && script.match(/\/etc\/init\/\S+\.conf/)
   end
 
   def version_is_pre_0_6_7
@@ -263,7 +256,7 @@ private
   end
 
   def read_override_file
-    if File.exists?(overscript)
+    if Puppet::FileSystem::File.exist?(overscript)
       read_script_from(overscript)
     else
       ""
