@@ -17,7 +17,7 @@ Puppet::Reports.register_report(:store) do
 
     dir = File.join(Puppet[:reportdir], host)
 
-    if ! FileTest.exists?(dir)
+    if ! Puppet::FileSystem::File.exist?(dir)
       FileUtils.mkdir_p(dir)
       FileUtils.chmod_R(0750, dir)
     end
@@ -41,8 +41,7 @@ Puppet::Reports.register_report(:store) do
       end
       FileUtils.mv(f.path, file)
     rescue => detail
-      puts detail.backtrace if Puppet[:trace]
-      Puppet.warning "Could not write report for #{host} at #{file}: #{detail}"
+      Puppet.log_exception(detail, "Could not write report for #{host} at #{file}: #{detail}")
     end
 
     # Only testing cares about the return value
@@ -55,11 +54,11 @@ Puppet::Reports.register_report(:store) do
 
     dir = File.join(Puppet[:reportdir], host)
 
-    if File.exists?(dir)
+    if Puppet::FileSystem::File.exist?(dir)
       Dir.entries(dir).each do |file|
         next if ['.','..'].include?(file)
         file = File.join(dir, file)
-        File.unlink(file) if File.file?(file)
+        Puppet::FileSystem::File.unlink(file) if File.file?(file)
       end
       Dir.rmdir(dir)
     end
