@@ -6,6 +6,14 @@ require 'puppet/parser/ast/leaf'
 require 'puppet/parser/ast/block_expression'
 require 'puppet/dsl'
 
+# Puppet::Resource::Type represents nodes, classes and defined types.
+#
+# It has a standard format for external consumption, usable from the
+# resource_type indirection via rest and the resource_type face. See the
+# {file:api_docs/http_resource_type.md#Schema resource type schema
+# description}.
+#
+# @api public
 class Puppet::Resource::Type
   Puppet::ResourceType = self
   include Puppet::Util::InlineDocs
@@ -14,13 +22,7 @@ class Puppet::Resource::Type
 
   RESOURCE_KINDS = [:hostclass, :node, :definition]
 
-  # We have reached a point where we've established some naming conventions
-  #  in our documentation that don't entirely match up with our internal names
-  #  for things.  Ideally we'd change the internal representation to match the
-  #  conventions expressed in our docs, but that would be a fairly far-reaching
-  #  and risky change.  For the time being, we're settling for mapping the
-  #  internal names to the external ones (and vice-versa) during serialization
-  #  and deserialization.  These two hashes is here to help with that mapping.
+  # Map the names used in our documentation to the names used internally
   RESOURCE_KINDS_TO_EXTERNAL_NAMES = {
       :hostclass => "class",
       :node => "node",
@@ -54,41 +56,26 @@ class Puppet::Resource::Type
 
     data = data.inject({}) { |result, ary| result[ary[0].intern] = ary[1]; result }
 
-    # This is a bit of a hack; when we serialize, we use the term "parameters" because that
-    #  is the terminology that we use in our documentation.  However, internally to this
-    #  class we use the term "arguments".  Ideally we'd change the implementation to be consistent
-    #  with the documentation, but that would be challenging right now because it could potentially
-    #  touch a lot of places in the code, not to mention that we already have another meaning for
-    #  "parameters" internally.  So, for now, we will simply transform the internal "arguments"
-    #  value to "parameters" when serializing, and the opposite when deserializing.
-    #     --cprice 2012-04-23
+    # External documentation uses "parameters" but the internal name
+    # is "arguments"
     data[:arguments] = data.delete(:parameters)
 
     new(type, name, data)
   end
 
-  # This method doesn't seem like it has anything to do with PSON in particular, and it shouldn't.
-  #  It's just transforming to a simple object that can be serialized and de-serialized via
-  #  any transport format.  Should probably be renamed if we get a chance to clean up our
-  #  serialization / deserialization, and there are probably many other similar methods in
-  #  other classes.
-  #  --cprice 2012-04-23
+  def to_pson(*args)
+    to_data_hash.to_pson(*args)
+  end
 
-  def to_pson_data_hash
+  def to_data_hash
     data = [:doc, :line, :file, :parent].inject({}) do |hash, param|
       next hash unless (value = self.send(param)) and (value != "")
       hash[param.to_s] = value
       hash
     end
 
-    # This is a bit of a hack; when we serialize, we use the term "parameters" because that
-    #  is the terminology that we use in our documentation.  However, internally to this
-    #  class we use the term "arguments".  Ideally we'd change the implementation to be consistent
-    #  with the documentation, but that would be challenging right now because it could potentially
-    #  touch a lot of places in the code, not to mention that we already have another meaning for
-    #  "parameters" internally.  So, for now, we will simply transform the internal "arguments"
-    #  value to "parameters" when serializing, and the opposite when deserializing.
-    #     --cprice 2012-04-23
+    # External documentation uses "parameters" but the internal name
+    # is "arguments"
     data['parameters'] = arguments.dup unless arguments.empty?
 
     data['name'] = name
@@ -100,19 +87,6 @@ class Puppet::Resource::Type
     data
   end
 
-  # It seems wrong that we have a 'to_pson' method on this class, but not a 'to_yaml'.
-  #  As a result, if you use the REST API to retrieve one or more objects of this type,
-  #  you will receive different data if you use 'Accept: yaml' vs 'Accept: pson'.  That
-  #  seems really, really wrong.  The "Accept" header should never affect what data is
-  #  being returned--only the format of the data.  If the data itself is going to differ,
-  #  then there should be a different request URL.  Documenting the REST API becomes
-  #  a much more complex problem when the "Accept" header can change the semantics
-  #  of the response.  --cprice 2012-04-23
-
-  def to_pson(*args)
-    to_pson_data_hash.to_pson(*args)
-  end
-
   # Are we a child of the passed class?  Do a recursive search up our
   # parentage tree to figure it out.
   def child_of?(klass)
@@ -134,7 +108,19 @@ class Puppet::Resource::Type
 
     resource.add_edge_to_stage
 
-    code.safeevaluate(scope) if code
+    if code
+      if @match # Only bother setting up the ephemeral scope if there are match variables to add into it
+        begin
+          elevel = scope.ephemeral_level
+          scope.ephemeral_from(@match, file, line)
+          code.safeevaluate(scope)
+        ensure
+          scope.unset_ephemeral_var(elevel)
+        end
+      else
+        code.safeevaluate(scope)
+      end
+    end
 
     evaluate_ruby_code(resource, scope) if ruby_code
   end
@@ -154,6 +140,8 @@ class Puppet::Resource::Type
 
     set_arguments(options[:arguments])
 
+    @match = nil
+
     @module_name = options[:module_name]
   end
 
@@ -162,7 +150,7 @@ class Puppet::Resource::Type
   def match(string)
     return string.to_s.downcase == name unless name_is_regex?
 
-    @name =~ string
+    @match = @name.match(string)
   end
 
   # Add code from a new instance to our code.
@@ -242,7 +230,6 @@ class Puppet::Resource::Type
 
   def assign_parameter_values(parameters, resource)
     return unless parameters
-    scope = resource.scope || {}
 
     # It'd be nice to assign default parameter values here,
     # but we can't because they often rely on local variables
