@@ -1,14 +1,19 @@
 require 'puppet/parser/type_loader'
+require 'puppet/util/file_watcher'
+require 'puppet/util/warnings'
 
 class Puppet::Resource::TypeCollection
   attr_reader :environment
   attr_accessor :parse_failed
 
+  include Puppet::Util::Warnings
+
   def clear
     @hostclasses.clear
     @definitions.clear
     @nodes.clear
     @watched_files.clear
+    @notfound.clear
   end
 
   def initialize(env)
@@ -16,11 +21,12 @@ class Puppet::Resource::TypeCollection
     @hostclasses = {}
     @definitions = {}
     @nodes = {}
+    @notfound = {}
 
     # So we can keep a list and match the first-defined regex
     @node_list = []
 
-    @watched_files = {}
+    @watched_files = Puppet::Util::FileWatcher.new
   end
 
   def import_ast(ast, modname)
@@ -109,8 +115,8 @@ class Puppet::Resource::TypeCollection
     @nodes[munge_name(name)]
   end
 
-  def find_hostclass(namespaces, name)
-    find_or_load(namespaces, name, :hostclass)
+  def find_hostclass(namespaces, name, options = {})
+    find_or_load(namespaces, name, :hostclass, options)
   end
 
   def find_definition(namespaces, name)
@@ -128,29 +134,29 @@ class Puppet::Resource::TypeCollection
   end
 
   def stale?
-    @watched_files.values.detect { |file| file.changed? }
+    @watched_files.changed?
   end
 
   def version
-    return @version if defined?(@version)
-
-    if environment[:config_version] == ""
-      @version = Time.now.to_i
-      return @version
+    if !defined?(@version)
+      if environment[:config_version] == ""
+        @version = Time.now.to_i
+      else
+        @version = Puppet::Util::Execution.execute([environment[:config_version]]).strip
+      end
     end
 
-    @version = Puppet::Util.execute([environment[:config_version]]).strip
-
+    @version
   rescue Puppet::ExecutionFailure => e
-    raise Puppet::ParseError, "Unable to set config_version: #{e.message}"
+    raise Puppet::ParseError, "Execution of config_version command `#{environment[:config_version]}` failed: #{e.message}"
   end
 
-  def watch_file(file)
-    @watched_files[file] = Puppet::Util::LoadedFile.new(file)
+  def watch_file(filename)
+    @watched_files.watch(filename)
   end
 
-  def watching_file?(file)
-    @watched_files.include?(file)
+  def watching_file?(filename)
+    @watched_files.watching?(filename)
   end
 
   private
@@ -192,14 +198,23 @@ class Puppet::Resource::TypeCollection
 
   # Resolve namespaces and find the given object.  Autoload it if
   # necessary.
-  def find_or_load(namespaces, name, type)
-    resolve_namespaces(namespaces, name).each do |fqname|
-      if result = send(type, fqname) || loader.try_load_fqname(type, fqname)
-        return result
+  def find_or_load(namespaces, name, type, options = {})
+    searchspace = options[:assume_fqname] ? [name].flatten : resolve_namespaces(namespaces, name)
+    searchspace.each do |fqname|
+      result = send(type, fqname)
+      unless result
+        if @notfound[fqname] and Puppet[:ignoremissingtypes]
+          # do not try to autoload if we already tried and it wasn't conclusive
+          # as this is a time consuming operation. Warn the user.
+          debug_once "Not attempting to load #{type} #{fqname} as this object was missing during a prior compilation"
+        else
+          result = loader.try_load_fqname(type, fqname)
+          @notfound[fqname] = result.nil?
+        end
       end
+      return result if result
     end
 
-    # Nothing found.
     return nil
   end
 
