@@ -34,13 +34,7 @@ Puppet::Type.newtype(:component) do
   # Component paths are special because they function as containers.
   def pathbuilder
     if reference.type == "Class"
-      # 'main' is the top class, so we want to see '//' instead of
-      # its name.
-      if reference.title.to_s.downcase == "main"
-        myname = ""
-      else
-        myname = reference.title
-      end
+      myname = reference.title
     else
       myname = reference.to_s
     end
