@@ -19,7 +19,7 @@ Puppet::Type.newtype(:k5login) do
     desc "The path to the `.k5login` file to manage.  Must be fully qualified."
 
     validate do |value|
-      unless value =~ /^#{File::SEPARATOR}/
+      unless absolute_path?(value)
         raise Puppet::Error, "File paths must be fully qualified."
       end
     end
@@ -37,7 +37,7 @@ Puppet::Type.newtype(:k5login) do
 
     # Does this file exist?
     def exists?
-      File.exists?(@resource[:name])
+      Puppet::FileSystem::File.exist?(@resource[:name])
     end
 
     # create the file
@@ -51,12 +51,12 @@ Puppet::Type.newtype(:k5login) do
 
     # remove the file
     def destroy
-      File.unlink(@resource[:name])
+      Puppet::FileSystem::File.unlink(@resource[:name])
     end
 
     # Return the principals
     def principals(dummy_argument=:work_arround_for_ruby_GC_bug)
-      if File.exists?(@resource[:name])
+      if Puppet::FileSystem::File.exist?(@resource[:name])
         File.readlines(@resource[:name]).collect { |line| line.chomp }
       else
         :absent
@@ -70,7 +70,7 @@ Puppet::Type.newtype(:k5login) do
 
     # Return the mode as an octal string, not as an integer
     def mode
-      "%o" % (File.stat(@resource[:name]).mode & 007777)
+      "%o" % (Puppet::FileSystem::File.new(@resource[:name]).stat.mode & 007777)
     end
 
     # Set the file mode, converting from a string to an integer.
