@@ -41,16 +41,23 @@ class Puppet::Util::Instrumentation::Listener
     { :data => @listener.data }
   end
 
-  def to_pson(*args)
-    result = {
-      :document_type => "Puppet::Util::Instrumentation::Listener",
-      :data => {
-        :name => name,
-        :pattern => pattern,
-        :enabled => enabled?
-      }
+  def to_data_hash
+    {
+      :name => name,
+      :pattern => pattern,
+      :enabled => enabled?
     }
-    result.to_pson(*args)
+  end
+
+  def to_pson_data_hash
+    {
+      :document_type => "Puppet::Util::Instrumentation::Listener",
+      :data => to_data_hash,
+    }
+  end
+
+  def to_pson(*args)
+    to_pson_data_hash.to_pson(*args)
   end
 
   def self.from_pson(data)
