@@ -7,7 +7,7 @@ class Puppet::Util::NetworkDevice::Base
 
   attr_accessor :url, :transport
 
-  def initialize(url)
+  def initialize(url, options = {})
     @url = URI.parse(url)
 
     @autoloader = Puppet::Util::Autoload.new(
@@ -17,7 +17,7 @@ class Puppet::Util::NetworkDevice::Base
     )
 
     if @autoloader.load(@url.scheme)
-      @transport = Puppet::Util::NetworkDevice::Transport.const_get(@url.scheme.capitalize).new
+      @transport = Puppet::Util::NetworkDevice::Transport.const_get(@url.scheme.capitalize).new(options[:debug])
       @transport.host = @url.host
       @transport.port = @url.port || case @url.scheme ; when "ssh" ; 22 ; when "telnet" ; 23 ; end
       @transport.user = @url.user
