@@ -3,7 +3,7 @@ require 'puppet/util/windows'
 # represents an error resulting from a Win32 error code
 class Puppet::Util::Windows::Error < Puppet::Error
   require 'windows/error'
-  include Windows::Error
+  include ::Windows::Error
 
   attr_reader :code
 
