@@ -1,4 +1,4 @@
-#! /usr/bin/env ruby -S rspec
+#! /usr/bin/env ruby
 require 'spec_helper'
 
 require 'puppet_spec/files'
@@ -12,12 +12,12 @@ describe Puppet::Type.type(:tidy) do
   end
 
   # Testing #355.
-  it "should be able to remove dead links", :unless => Puppet.features.microsoft_windows? do
+  it "should be able to remove dead links", :if => Puppet.features.manages_symlinks? do
     dir = tmpfile("tidy_link_testing")
     link = File.join(dir, "link")
     target = tmpfile("no_such_file_tidy_link_testing")
     Dir.mkdir(dir)
-    File.symlink(target, link)
+    Puppet::FileSystem::File.new(target).symlink(link)
 
     tidy = Puppet::Type.type(:tidy).new :path => dir, :recurse => true
 
@@ -26,6 +26,6 @@ describe Puppet::Type.type(:tidy) do
 
     catalog.apply
 
-    FileTest.should_not be_symlink(link)
+    Puppet::FileSystem::File.new(link).symlink?.should be_false
   end
 end
