@@ -1,4 +1,4 @@
-#! /usr/bin/env ruby -S rspec
+#! /usr/bin/env ruby
 require 'spec_helper'
 require 'puppet/agent'
 require 'puppet/agent/locker'
@@ -23,15 +23,21 @@ describe Puppet::Agent::Locker do
     @locker.send(:lockfile).should be_instance_of(Puppet::Util::Pidlock)
   end
 
-  it "should use puppet's :agent_pidfile' setting to determine its lockfile path" do
+  it "should use puppet's agent_catalog_run_lockfile' setting to determine its lockfile path" do
     lockfile = File.expand_path("/my/lock")
-    Puppet[:agent_pidfile] = lockfile
+    Puppet[:agent_catalog_run_lockfile] = lockfile
     lock = Puppet::Util::Pidlock.new(lockfile)
     Puppet::Util::Pidlock.expects(:new).with(lockfile).returns lock
 
     @locker.send(:lockfile)
   end
 
+  it "#lockfile_path provides the path to the lockfile" do
+    lockfile = File.expand_path("/my/lock")
+    Puppet[:agent_catalog_run_lockfile] = lockfile
+    @locker.lockfile_path.should == File.expand_path("/my/lock")
+  end
+
   it "should reuse the same lock file each time" do
     @locker.send(:lockfile).should equal(@locker.send(:lockfile))
   end
