@@ -3,6 +3,16 @@ require 'spec_helper'
 require 'puppet/configurer'
 require 'puppet/configurer/fact_handler'
 
+# the json-schema gem doesn't support windows
+if not Puppet.features.microsoft_windows?
+  describe "catalog facts schema" do
+    it "should validate against the json meta-schema" do
+      JSON::Validator.validate!(JSON_META_SCHEMA, FACTS_SCHEMA)
+    end
+  end
+
+ end
+
 class FactHandlerTester
   include Puppet::Configurer::FactHandler
 
@@ -74,4 +84,17 @@ describe Puppet::Configurer::FactHandler do
 
     @facthandler.facts_for_uploading.should == {:facts_format => :pson, :facts => text}
   end
+
+  def validate_json_for_facts(catalog_facts)
+    JSON::Validator.validate!(FACTS_SCHEMA, catalog_facts)
+  end
+
+  it "should generate valid facts data against the facts schema", :unless => Puppet.features.microsoft_windows? do
+    facts = Puppet::Node::Facts.new(Puppet[:node_name_value], 'my_name_fact' => 'other_node_name')
+    Puppet::Node::Facts.indirection.save(facts)
+
+    validate_json_for_facts(CGI.unescape(@facthandler.facts_for_uploading[:facts]))
+  end
+
 end
+
