@@ -26,7 +26,8 @@ describe Puppet::FileServing::Content do
     content = Puppet::FileServing::Content.new(path)
 
     result = "foo"
-    File.stubs(:lstat).returns(stub("stat", :ftype => "file"))
+    stub_file = stub(path, :lstat => stub('stat', :ftype => "file"))
+    Puppet::FileSystem::File.expects(:new).with(path).returns stub_file
     File.expects(:read).with(path).never
     content.collect
 
@@ -37,7 +38,8 @@ describe Puppet::FileServing::Content do
     content = Puppet::FileServing::Content.new(path)
 
     result = "foo"
-    File.stubs(:lstat).returns(stub("stat", :ftype => "directory"))
+    stub_file = stub(path, :lstat => stub('stat', :ftype => "directory"))
+    Puppet::FileSystem::File.expects(:new).with(path).returns stub_file
     File.expects(:read).with(path).never
     content.collect
 
@@ -83,7 +85,8 @@ describe Puppet::FileServing::Content, "when returning the contents" do
 
   it "should fail if the file is a symlink and links are set to :manage" do
     content.links = :manage
-    File.expects(:lstat).with(path).returns stub("stat", :ftype => "symlink")
+    stub_file = stub(path, :lstat => stub("stat", :ftype => "symlink"))
+    Puppet::FileSystem::File.expects(:new).with(path).returns stub_file
     proc { content.content }.should raise_error(ArgumentError)
   end
 
@@ -97,14 +100,16 @@ describe Puppet::FileServing::Content, "when returning the contents" do
   end
 
   it "should return the contents of the path if the file exists" do
-    File.expects(:stat).with(path).returns stub("stat", :ftype => "file")
-    IO.expects(:binread).with(path).returns(:mycontent)
+    mocked_file = mock(path, :stat => stub('stat', :ftype => 'file'))
+    Puppet::FileSystem::File.expects(:new).with(path).twice.returns(mocked_file)
+    mocked_file.expects(:binread).returns(:mycontent)
     content.content.should == :mycontent
   end
 
   it "should cache the returned contents" do
-    File.expects(:stat).with(path).returns stub("stat", :ftype => "file")
-    IO.expects(:binread).with(path).returns(:mycontent)
+    mocked_file = mock(path, :stat => stub('stat', :ftype => 'file'))
+    Puppet::FileSystem::File.expects(:new).with(path).twice.returns(mocked_file)
+    mocked_file.expects(:binread).returns(:mycontent)
     content.content
     # The second run would throw a failure if the content weren't being cached.
     content.content
