@@ -3,6 +3,21 @@ require 'spec_helper'
 
 require 'puppet/file_serving/metadata'
 
+# the json-schema gem doesn't support windows
+if not Puppet.features.microsoft_windows?
+  FILE_METADATA_SCHEMA = JSON.parse(File.read(File.join(File.dirname(__FILE__), '../../../api/schemas/file_metadata.json')))
+
+  describe "catalog schema" do
+    it "should validate against the json meta-schema" do
+      JSON::Validator.validate!(JSON_META_SCHEMA, FILE_METADATA_SCHEMA)
+    end
+  end
+
+  def validate_json_for_file_metadata(file_metadata)
+    JSON::Validator.validate!(FILE_METADATA_SCHEMA, file_metadata.to_pson)
+  end
+end
+
 describe Puppet::FileServing::Metadata do
   let(:foobar) { File.expand_path('/foo/bar') }
 
@@ -84,7 +99,6 @@ describe Puppet::FileServing::Metadata do
     it "should pass the checksum in the hash verbatim as the checksum's value" do
       metadata.to_pson_data_hash['data']['checksum']['value'].should == metadata.checksum
     end
-
   end
 end
 
@@ -139,6 +153,10 @@ describe Puppet::FileServing::Metadata do
             metadata.checksum.should == "{mtime}#{@time}"
           end
         end
+
+        it "should validate against the schema", :unless => Puppet.features.microsoft_windows? do
+          validate_json_for_file_metadata(metadata)
+        end
       end
 
       describe "when managing directories" do
@@ -160,25 +178,45 @@ describe Puppet::FileServing::Metadata do
           metadata.collect
           metadata.checksum.should == "{ctime}#{time}"
         end
-      end
 
-      describe "when managing links", :unless => Puppet.features.microsoft_windows? do
+        it "should validate against the schema", :unless => Puppet.features.microsoft_windows? do
+          metadata.collect
+          validate_json_for_file_metadata(metadata)
+        end
+      end
+    end
+  end
+
+  shared_examples_for "metadata collector symlinks" do
+
+    let(:metadata) do
+      data = described_class.new(path)
+      data.collect
+      data
+    end
+
+    describe "when collecting attributes" do
+      describe "when managing links" do
         # 'path' is a link that points to 'target'
         let(:path) { tmpfile('file_serving_metadata_link') }
         let(:target) { tmpfile('file_serving_metadata_target') }
         let(:checksum) { Digest::MD5.hexdigest("some content\n") }
-        let(:fmode) { File.lstat(path).mode & 0777 }
+        let(:fmode) { Puppet::FileSystem::File.new(path).lstat.mode & 0777 }
 
         before :each do
           File.open(target, "wb") {|f| f.print("some content\n")}
           set_mode(0644, target)
 
-          FileUtils.symlink(target, path)
+          Puppet::FileSystem::File.new(target).symlink(path)
         end
 
         it "should read links instead of returning their checksums" do
           metadata.destination.should == target
         end
+
+        it "should validate against the schema", :unless => Puppet.features.microsoft_windows? do
+          validate_json_for_file_metadata(metadata)
+        end
       end
     end
 
@@ -209,6 +247,10 @@ describe Puppet::FileServing::Metadata do
 
         proc { metadata.collect}.should raise_error(Errno::ENOENT)
       end
+
+      it "should validate against the schema", :unless => Puppet.features.microsoft_windows? do
+        validate_json_for_file_metadata(metadata)
+      end
     end
   end
 
@@ -222,6 +264,7 @@ describe Puppet::FileServing::Metadata do
     end
 
     it_should_behave_like "metadata collector"
+    it_should_behave_like "metadata collector symlinks"
 
     def set_mode(mode, path)
       File.chmod(mode, path)
@@ -239,6 +282,7 @@ describe Puppet::FileServing::Metadata do
     end
 
     it_should_behave_like "metadata collector"
+    it_should_behave_like "metadata collector symlinks" if Puppet.features.manages_symlinks?
 
     describe "if ACL metadata cannot be collected" do
       let(:path) { tmpdir('file_serving_metadata_acl') }
@@ -274,16 +318,24 @@ describe Puppet::FileServing::Metadata do
 end
 
 
-describe Puppet::FileServing::Metadata, " when pointing to a link", :unless => Puppet.features.microsoft_windows? do
+describe Puppet::FileServing::Metadata, " when pointing to a link", :if => Puppet.features.manages_symlinks? do
   describe "when links are managed" do
     before do
-      @file = Puppet::FileServing::Metadata.new("/base/path/my/file", :links => :manage)
-      File.expects(:lstat).with("/base/path/my/file").returns stub("stat", :uid => 1, :gid => 2, :ftype => "link", :mode => 0755)
-      File.expects(:readlink).with("/base/path/my/file").returns "/some/other/path"
-
+      path = "/base/path/my/file"
+      @file = Puppet::FileServing::Metadata.new(path, :links => :manage)
+      stat = stub("stat", :uid => 1, :gid => 2, :ftype => "link", :mode => 0755)
+      stub_file = stub(:readlink => "/some/other/path", :lstat => stat)
+      Puppet::FileSystem::File.expects(:new).with(path).at_least_once.returns stub_file
       @checksum = Digest::MD5.hexdigest("some content\n") # Remove these when :managed links are no longer checksumed.
       @file.stubs(:md5_file).returns(@checksum)           #
+
+      if Puppet.features.microsoft_windows?
+        win_stat = stub('win_stat', :owner => 'snarf', :group => 'thundercats',
+          :ftype => 'link', :mode => 0755)
+        Puppet::FileServing::Metadata::WindowsStat.stubs(:new).returns win_stat
+      end
     end
+
     it "should store the destination of the link in :destination if links are :manage" do
       @file.collect
       @file.destination.should == "/some/other/path"
@@ -301,9 +353,19 @@ describe Puppet::FileServing::Metadata, " when pointing to a link", :unless => P
 
   describe "when links are followed" do
     before do
-      @file = Puppet::FileServing::Metadata.new("/base/path/my/file", :links => :follow)
-      File.expects(:stat).with("/base/path/my/file").returns stub("stat", :uid => 1, :gid => 2, :ftype => "file", :mode => 0755)
-      File.expects(:readlink).with("/base/path/my/file").never
+      path = "/base/path/my/file"
+      @file = Puppet::FileServing::Metadata.new(path, :links => :follow)
+      stat = stub("stat", :uid => 1, :gid => 2, :ftype => "file", :mode => 0755)
+      mocked_file = mock(path, :stat => stat)
+      Puppet::FileSystem::File.expects(:new).with(path).at_least_once.returns mocked_file
+      mocked_file.expects(:readlink).never
+
+      if Puppet.features.microsoft_windows?
+        win_stat = stub('win_stat', :owner => 'snarf', :group => 'thundercats',
+          :ftype => 'file', :mode => 0755)
+        Puppet::FileServing::Metadata::WindowsStat.stubs(:new).returns win_stat
+      end
+
       @checksum = Digest::MD5.hexdigest("some content\n")
       @file.stubs(:md5_file).returns(@checksum)
     end
