@@ -85,7 +85,7 @@ describe Puppet::FileServing::Mount::File do
     include FileServingMountTesting
 
     before do
-      FileTest.stubs(:exist?).returns(true)
+      Puppet::FileSystem::File.stubs(:exist?).returns(true)
       FileTest.stubs(:directory?).returns(true)
       FileTest.stubs(:readable?).returns(true)
       @mount = Puppet::FileServing::Mount::File.new("test")
@@ -95,12 +95,12 @@ describe Puppet::FileServing::Mount::File do
     end
 
     it "should return nil if the file is absent" do
-      FileTest.stubs(:exist?).returns(false)
+      Puppet::FileSystem::File.stubs(:exist?).returns(false)
       @mount.complete_path("/my/path", nil).should be_nil
     end
 
     it "should write a log message if the file is absent" do
-      FileTest.stubs(:exist?).returns(false)
+      Puppet::FileSystem::File.stubs(:exist?).returns(false)
 
       Puppet.expects(:info).with("File does not exist or is not accessible: /mount/my/path")
 
@@ -108,12 +108,12 @@ describe Puppet::FileServing::Mount::File do
     end
 
     it "should return the file path if the file is present" do
-      FileTest.stubs(:exist?).with("/my/path").returns(true)
+      Puppet::FileSystem::File.stubs(:exist?).with("/my/path").returns(true)
       @mount.complete_path("/my/path", nil).should == "/mount/my/path"
     end
 
     it "should treat a nil file name as the path to the mount itself" do
-      FileTest.stubs(:exist?).returns(true)
+      Puppet::FileSystem::File.stubs(:exist?).returns(true)
       @mount.complete_path(nil, nil).should == "/mount"
     end
 
@@ -141,7 +141,7 @@ describe Puppet::FileServing::Mount::File do
     include FileServingMountTesting
 
     before do
-      FileTest.stubs(:exist?).returns(true)
+      Puppet::FileSystem::File.stubs(:exist?).returns(true)
       FileTest.stubs(:directory?).returns(true)
       FileTest.stubs(:readable?).returns(true)
       @mount = Puppet::FileServing::Mount::File.new("test")
@@ -153,7 +153,7 @@ describe Puppet::FileServing::Mount::File do
     end
 
     it "should return the results of the complete file path" do
-      FileTest.stubs(:exist?).returns(false)
+      Puppet::FileSystem::File.stubs(:exist?).returns(false)
       @mount.expects(:complete_path).with("/my/path", "foo").returns "eh"
       @mount.find("/my/path", @request).should == "eh"
     end
@@ -163,7 +163,7 @@ describe Puppet::FileServing::Mount::File do
     include FileServingMountTesting
 
     before do
-      FileTest.stubs(:exist?).returns(true)
+      Puppet::FileSystem::File.stubs(:exist?).returns(true)
       FileTest.stubs(:directory?).returns(true)
       FileTest.stubs(:readable?).returns(true)
       @mount = Puppet::FileServing::Mount::File.new("test")
@@ -175,13 +175,13 @@ describe Puppet::FileServing::Mount::File do
     end
 
     it "should return the results of the complete file path as an array" do
-      FileTest.stubs(:exist?).returns(false)
+      Puppet::FileSystem::File.stubs(:exist?).returns(false)
       @mount.expects(:complete_path).with("/my/path", "foo").returns "eh"
       @mount.search("/my/path", @request).should == ["eh"]
     end
 
     it "should return nil if the complete path is nil" do
-      FileTest.stubs(:exist?).returns(false)
+      Puppet::FileSystem::File.stubs(:exist?).returns(false)
       @mount.expects(:complete_path).with("/my/path", "foo").returns nil
       @mount.search("/my/path", @request).should be_nil
     end
