@@ -89,9 +89,11 @@ describe "Puppet::Resource::Catalog::ActiveRecord", :if => can_use_scratch_datab
     end
 
     it "should set the last compile time on the host" do
-      now = Time.now
+      before = Time.now
       terminus.save(request)
-      Puppet::Rails::Host.find_by_name("foo").last_compile.should be_within(1).of(now)
+      after = Time.now
+
+      Puppet::Rails::Host.find_by_name("foo").last_compile.should be_between(before, after)
     end
 
     it "should save the Rails host instance" do
