@@ -48,6 +48,9 @@ describe Puppet::Node::Facts::Facter do
     Facter.stubs(:to_hash).returns({})
     @name = "me"
     @request = stub 'request', :key => @name
+    @environment = stub 'environment'
+    @request.stubs(:environment).returns(@environment)
+    @request.environment.stubs(:modules).returns([])
   end
 
   describe Puppet::Node::Facts::Facter, " when finding facts" do
@@ -58,6 +61,15 @@ describe Puppet::Node::Facts::Facter do
       @facter.find(@request)
     end
 
+    it "should include external facts when feature is present" do
+      clear = sequence 'clear'
+      Puppet.features.stubs(:external_facts?).returns(:true)
+      Puppet::Node::Facts::Facter.expects(:setup_external_facts).in_sequence(clear)
+      Puppet::Node::Facts::Facter.expects(:reload_facter).in_sequence(clear)
+      Puppet::Node::Facts::Facter.expects(:load_fact_plugins).in_sequence(clear)
+      @facter.find(@request)
+    end
+
     it "should return a Facts instance" do
       @facter.find(@request).should be_instance_of(Puppet::Node::Facts)
     end
@@ -131,6 +143,20 @@ describe Puppet::Node::Facts::Facter do
     Puppet::Node::Facts::Facter.load_facts_in_dir("mydir")
   end
 
+  it "should include pluginfactdest when loading external facts",
+     :if => Puppet.features.external_facts?, :unless => Puppet.features.microsoft_windows? do
+    Puppet[:pluginfactdest] = "/plugin/dest"
+    @facter.find(@request)
+    Facter::Util::Config.external_facts_dirs.include?("/plugin/dest")
+  end
+
+  it "should include pluginfactdest when loading external facts",
+    :if => Puppet.features.external_facts?, :if => Puppet.features.microsoft_windows? do
+    Puppet[:pluginfactdest] = "/plugin/dest"
+    @facter.find(@request)
+    Facter::Util::Config.external_facts_dirs.include?("C:/plugin/dest")
+  end
+
   describe "when loading fact plugins from disk" do
     let(:one) { File.expand_path("one") }
     let(:two) { File.expand_path("two") }
@@ -160,5 +186,12 @@ describe Puppet::Node::Facts::Facter do
 
       Puppet::Node::Facts::Facter.load_fact_plugins
     end
+
+    it "should include module plugin facts when present", :if => Puppet.features.external_facts? do
+      mod = Puppet::Module.new("mymodule", "#{one}/mymodule", @request.environment)
+      @request.environment.stubs(:modules).returns([mod])
+      @facter.find(@request)
+      Facter::Util::Config.external_facts_dirs.include?("#{one}/mymodule/facts.d")
+    end
   end
 end
