@@ -64,23 +64,19 @@ describe Puppet::ModuleTool::Applications::Uninstaller do
     context "when the module is installed" do
 
       it "should uninstall the module" do
-        pending("porting to Windows", :if => Puppet.features.microsoft_windows?) do
-          PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
+        PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
 
-          results = @uninstaller.new("puppetlabs-foo", options).run
-          results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
-        end
+        results = @uninstaller.new("puppetlabs-foo", options).run
+        results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
       end
 
       it "should only uninstall the requested module" do
-        pending("porting to Windows", :if => Puppet.features.microsoft_windows?) do
-          PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
-          PuppetSpec::Modules.create('bar', modpath1, :metadata => bar_metadata)
+        PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
+        PuppetSpec::Modules.create('bar', modpath1, :metadata => bar_metadata)
 
-          results = @uninstaller.new("puppetlabs-foo", options).run
-          results[:affected_modules].length == 1
-          results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
-        end
+        results = @uninstaller.new("puppetlabs-foo", options).run
+        results[:affected_modules].length == 1
+        results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
       end
 
       it "should uninstall fail if a module exists twice in the modpath" do
@@ -93,16 +89,14 @@ describe Puppet::ModuleTool::Applications::Uninstaller do
       context "when options[:version] is specified" do
 
         it "should uninstall the module if the version matches" do
-          pending("porting to Windows", :if => Puppet.features.microsoft_windows?) do
-            PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
+          PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
 
-            options[:version] = "1.0.0"
+          options[:version] = "1.0.0"
 
-            results = @uninstaller.new("puppetlabs-foo", options).run
-            results[:affected_modules].length.should == 1
-            results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
-            results[:affected_modules].first.version.should == "1.0.0"
-          end
+          results = @uninstaller.new("puppetlabs-foo", options).run
+          results[:affected_modules].length.should == 1
+          results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
+          results[:affected_modules].first.version.should == "1.0.0"
         end
 
         it "should not uninstall the module if the version does not match" do
@@ -137,13 +131,11 @@ describe Puppet::ModuleTool::Applications::Uninstaller do
       context "when the module does not have local changes" do
 
         it "should uninstall the module" do
-          pending("porting to Windows", :if => Puppet.features.microsoft_windows?) do
-            PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
+          PuppetSpec::Modules.create('foo', modpath1, :metadata => foo_metadata)
 
-            results = @uninstaller.new("puppetlabs-foo", options).run
-            results[:affected_modules].length.should == 1
-            results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
-          end
+          results = @uninstaller.new("puppetlabs-foo", options).run
+          results[:affected_modules].length.should == 1
+          results[:affected_modules].first.forge_name.should == "puppetlabs/foo"
         end
       end
 
