@@ -5,7 +5,8 @@ require 'puppet/network/authconfig'
 
 describe Puppet::Network::AuthConfig do
   before :each do
-    File.stubs(:stat).returns(stub('stat', :ctime => :now))
+    stub_file = stub('file', :stat => stub('stat', :ctime => :now))
+    Puppet::FileSystem::File.stubs(:new).returns stub_file
     Time.stubs(:now).returns Time.now
 
     Puppet::Network::AuthConfig.any_instance.stubs(:exists?).returns(true)
