@@ -38,6 +38,9 @@ describe Puppet::Network::HTTP::Handler do
     end
 
     class Puppet::TestModel::Memory < Puppet::Indirector::Memory
+      def supports_remote_requests?
+        true
+      end
     end
 
     Puppet::TestModel.indirection.terminus_class = :memory
@@ -150,9 +153,7 @@ describe Puppet::Network::HTTP::Handler do
 
   describe "when processing a request" do
     let(:response) do
-      obj = stub "http 200 ok"
-      obj.stubs(:[]=).with(Puppet::Network::HTTP::HEADER_PUPPET_VERSION, Puppet.version)
-      obj
+      { :status => 200 }
     end
 
     before do
@@ -163,7 +164,6 @@ describe Puppet::Network::HTTP::Handler do
     it "should check the client certificate for upcoming expiration" do
       request = a_request
       cert = mock 'cert'
-      handler.stubs(:uri2indirection).returns(["facts", :mymethod, "key", {:node => "name"}])
       handler.expects(:client_cert).returns(cert).with(request)
       handler.expects(:warn_if_near_expiration).with(cert)
 
@@ -201,17 +201,6 @@ describe Puppet::Network::HTTP::Handler do
       handler.process(request, response)
     end
 
-    it "should call the 'do' method and delegate authorization to the authorization layer" do
-      request = a_request
-      handler.expects(:uri2indirection).returns(["facts", :mymethod, "key", {:node => "name"}])
-
-      handler.expects(:do_mymethod).with("facts", "key", {:node => "name"}, request, response)
-
-      handler.expects(:check_authorization).with("facts", :mymethod, "key", {:node => "name"})
-
-      handler.process(request, response)
-    end
-
     it "should return 403 if the request is not authorized" do
       request = a_request
       handler.expects(:uri2indirection).returns(["facts", :mymethod, "key", {:node => "name"}])
@@ -225,9 +214,18 @@ describe Puppet::Network::HTTP::Handler do
       handler.process(request, response)
     end
 
-    it "should serialize a controller exception when an exception is thrown while finding the model instance" do
+    it "should return an error code if the indirection does not support remote requests" do
       request = a_request
-      handler.expects(:uri2indirection).returns(["facts", :find, "key", {:node => "name"}])
+
+      indirection.expects(:allow_remote_requests?).returns(false)
+
+      handler.process(request, response)
+
+      expect(response[:status]).to eq 404
+    end
+
+    it "should serialize a controller exception when an exception is thrown while finding the model instance" do
+      request = a_request_that_finds(Puppet::TestModel.new("key"))
 
       handler.expects(:do_find).raises(ArgumentError, "The exception")
       handler.expects(:set_response).with(anything, "The exception", 400)
@@ -302,7 +300,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, data.render(:pson))
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:pson))
 
-        handler.do_find(indirection.name, "my data", {}, request, response)
+        handler.do_find(indirection, "my data", {}, request, response)
       end
 
       it "responds with a 406 error when no accept header is provided" do
@@ -311,7 +309,7 @@ describe Puppet::Network::HTTP::Handler do
         request = a_request_that_finds(data, :accept_header => nil)
 
         expect do
-          handler.do_find(indirection.name, "my data", {}, request, response)
+          handler.do_find(indirection, "my data", {}, request, response)
         end.to raise_error(Puppet::Network::HTTP::Handler::HTTPNotAcceptableError)
       end
 
@@ -321,7 +319,7 @@ describe Puppet::Network::HTTP::Handler do
         request = a_request_that_finds(data, :accept_header => "unknown, also/unknown")
 
         expect do
-          handler.do_find(indirection.name, "my data", {}, request, response)
+          handler.do_find(indirection, "my data", {}, request, response)
         end.to raise_error(Puppet::Network::HTTP::Handler::HTTPNotAcceptableError)
       end
 
@@ -334,7 +332,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, data_string)
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:pson))
 
-        handler.do_find(indirection.name, "my data", {}, request, response)
+        handler.do_find(indirection, "my data", {}, request, response)
       end
 
       it "should return a 404 when no model instance can be found" do
@@ -342,7 +340,7 @@ describe Puppet::Network::HTTP::Handler do
         request = a_request_that_finds(data, :accept_header => "unknown, pson, yaml")
 
         expect do
-          handler.do_find(indirection.name, "my data", {}, request, response)
+          handler.do_find(indirection, "my data", {}, request, response)
         end.to raise_error(Puppet::Network::HTTP::Handler::HTTPNotFoundError)
       end
     end
@@ -377,7 +375,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, Puppet::TestModel.render_multiple(:pson, [data]))
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:pson))
 
-        handler.do_search(indirection.name, "my", {}, request, response)
+        handler.do_search(indirection, "my", {}, request, response)
       end
 
       it "should return [] when searching returns an empty array" do
@@ -386,7 +384,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, Puppet::TestModel.render_multiple(:pson, []))
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:pson))
 
-        handler.do_search(indirection.name, "nothing", {}, request, response)
+        handler.do_search(indirection, "nothing", {}, request, response)
       end
 
       it "should return a 404 when searching returns nil" do
@@ -394,7 +392,7 @@ describe Puppet::Network::HTTP::Handler do
         indirection.expects(:search).returns(nil)
 
         expect do
-          handler.do_search(indirection.name, "nothing", {}, request, response)
+          handler.do_search(indirection, "nothing", {}, request, response)
         end.to raise_error(Puppet::Network::HTTP::Handler::HTTPNotFoundError)
       end
     end
@@ -405,7 +403,7 @@ describe Puppet::Network::HTTP::Handler do
         indirection.save(data, "my data")
         request = a_request_that_destroys(data)
 
-        handler.do_destroy(indirection.name, "my data", {}, request, response)
+        handler.do_destroy(indirection, "my data", {}, request, response)
 
         Puppet::TestModel.indirection.find("my data").should be_nil
       end
@@ -418,7 +416,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, data.render(:yaml))
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:yaml))
 
-        handler.do_destroy(indirection.name, "my data", {}, request, response)
+        handler.do_destroy(indirection, "my data", {}, request, response)
       end
 
       it "uses the first supported format for the response" do
@@ -429,7 +427,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, data.render(:pson))
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:pson))
 
-        handler.do_destroy(indirection.name, "my data", {}, request, response)
+        handler.do_destroy(indirection, "my data", {}, request, response)
       end
 
       it "raises an error and does not destory when no accepted formats are known" do
@@ -438,7 +436,7 @@ describe Puppet::Network::HTTP::Handler do
         request = a_request_that_submits(data, :accept_header => "unknown, also/unknown")
 
         expect do
-          handler.do_destroy(indirection.name, "my data", {}, request, response)
+          handler.do_destroy(indirection, "my data", {}, request, response)
         end.to raise_error(Puppet::Network::HTTP::Handler::HTTPNotAcceptableError)
 
         Puppet::TestModel.indirection.find("my data").should_not be_nil
@@ -460,7 +458,7 @@ describe Puppet::Network::HTTP::Handler do
         request[:content_type_header] = "application/x-raw"
         request[:body] = ''
 
-        handler.do_save(indirection.name, "test", {}, request, response)
+        handler.do_save(indirection, "test", {}, request, response)
 
         Puppet::TestModel.indirection.find("test").data.should == ''
       end
@@ -469,7 +467,7 @@ describe Puppet::Network::HTTP::Handler do
         data = Puppet::TestModel.new("my data", "some data")
         request = a_request_that_submits(data)
 
-        handler.do_save(indirection.name, "my data", {}, request, response)
+        handler.do_save(indirection, "my data", {}, request, response)
 
         Puppet::TestModel.indirection.find("my data").should == data
       end
@@ -481,7 +479,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, data.render(:yaml))
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:yaml))
 
-        handler.do_save(indirection.name, "my data", {}, request, response)
+        handler.do_save(indirection, "my data", {}, request, response)
       end
 
       it "uses the first supported format for the response" do
@@ -491,7 +489,7 @@ describe Puppet::Network::HTTP::Handler do
         handler.expects(:set_response).with(response, data.render(:pson))
         handler.expects(:set_content_type).with(response, Puppet::Network::FormatHandler.format(:pson))
 
-        handler.do_save(indirection.name, "my data", {}, request, response)
+        handler.do_save(indirection, "my data", {}, request, response)
       end
 
       it "raises an error and does not save when no accepted formats are known" do
@@ -499,7 +497,7 @@ describe Puppet::Network::HTTP::Handler do
         request = a_request_that_submits(data, :accept_header => "unknown, also/unknown")
 
         expect do
-          handler.do_save(indirection.name, "my data", {}, request, response)
+          handler.do_save(indirection, "my data", {}, request, response)
         end.to raise_error(Puppet::Network::HTTP::Handler::HTTPNotAcceptableError)
 
         Puppet::TestModel.indirection.find("my data").should be_nil
@@ -543,7 +541,8 @@ describe Puppet::Network::HTTP::Handler do
     end
 
     def set_response(response, body, status = 200)
-      "my_result"
+      response[:body] = body
+      response[:status] = status
     end
 
     def http_method(request)
