@@ -2,6 +2,17 @@
 require 'spec_helper'
 require 'matchers/json'
 
+# the json-schema gem doesn't support windows
+if not Puppet.features.microsoft_windows?
+  NODE_SCHEMA = JSON.parse(File.read(File.join(File.dirname(__FILE__), '../../api/schemas/node.json')))
+
+  describe "node schema" do
+    it "should validate against the json meta-schema" do
+      JSON::Validator.validate!(JSON_META_SCHEMA, NODE_SCHEMA)
+    end
+  end
+end
+
 describe Puppet::Node do
   it "should register its document type as Node" do
     PSON.registered_document_types["Node"].should equal(Puppet::Node)
@@ -55,6 +66,38 @@ describe Puppet::Node do
     new_node.name.should == node.name
   end
 
+  it "can round-trip through pson" do
+    facts = Puppet::Node::Facts.new("hello", "one" => "c", "two" => "b")
+    node = Puppet::Node.new("hello",
+                            :environment => 'kjhgrg',
+                            :classes => ['erth', 'aiu'],
+                            :parameters => {"hostname"=>"food"}
+                           )
+    new_node = Puppet::Node.convert_from('pson', node.render('pson'))
+    new_node.environment.should == node.environment
+    new_node.parameters.should == node.parameters
+    new_node.classes.should == node.classes
+    new_node.name.should == node.name
+  end
+
+  it "validates against the node json schema", :unless => Puppet.features.microsoft_windows? do
+    facts = Puppet::Node::Facts.new("hello", "one" => "c", "two" => "b")
+    node = Puppet::Node.new("hello",
+                            :environment => 'kjhgrg',
+                            :classes => ['erth', 'aiu'],
+                            :parameters => {"hostname"=>"food"}
+                           )
+    JSON::Validator.validate!(NODE_SCHEMA, node.to_pson)
+  end
+
+  it "when missing optional parameters validates against the node json schema", :unless => Puppet.features.microsoft_windows? do
+    facts = Puppet::Node::Facts.new("hello", "one" => "c", "two" => "b")
+    node = Puppet::Node.new("hello",
+                            :environment => 'kjhgrg'
+                           )
+    JSON::Validator.validate!(NODE_SCHEMA, node.to_pson)
+  end
+
   describe "when converting to json" do
     before do
       @node = Puppet::Node.new("mynode")
