@@ -1,5 +1,6 @@
 #! /usr/bin/env ruby
 require 'spec_helper'
+require 'puppet_spec/compiler'
 
 class CompilerTestResource
   attr_accessor :builtin, :virtual, :evaluated, :type, :title
@@ -106,22 +107,20 @@ describe Puppet::Parser::Compiler do
     @compiler.classlist.sort.should == %w{one two}.sort
   end
 
-  it "should clear the thread local caches before compile" do
+  it "should clear the global caches before compile" do
     compiler = stub 'compiler'
     Puppet::Parser::Compiler.expects(:new).with(@node).returns compiler
     catalog = stub 'catalog'
     compiler.expects(:compile).returns catalog
     catalog.expects(:to_resource)
 
-    [:known_resource_types, :env_module_directories].each do |var|
-      Thread.current[var] = "rspec"
-    end
+    $known_resource_types = "rspec"
+    $env_module_directories = "rspec"
 
     Puppet::Parser::Compiler.compile(@node)
 
-    [:known_resource_types, :env_module_directories].each do |var|
-      Thread.current[var].should == nil
-    end
+    $known_resource_types = nil
+    $env_module_directories = nil
   end
 
   describe "when initializing" do
@@ -218,27 +217,6 @@ describe Puppet::Parser::Compiler do
       @compiler.catalog.server_version.should == "3"
     end
 
-    it "should evaluate any existing classes named in the node" do
-      classes = %w{one two three four}
-      main = stub 'main'
-      one = stub 'one', :name => "one"
-      three = stub 'three', :name => "three"
-      @node.stubs(:name).returns("whatever")
-      @node.stubs(:classes).returns(classes)
-      compile_stub(:evaluate_node_classes)
-
-      @compiler.expects(:evaluate_classes).with(classes, @compiler.topscope)
-      @compiler.compile
-    end
-
-    it "should evaluate any parameterized classes named in the node" do
-      classes = {'foo'=>{'p1'=>'one'}, 'bar'=>{'p2'=>'two'}}
-      @node.stubs(:classes).returns(classes)
-      @compiler.expects(:evaluate_classes).with(classes, @compiler.topscope)
-      @compiler.compile
-    end
-
-
     it "should evaluate the main class if it exists" do
       compile_stub(:evaluate_main)
       main_class = @known_resource_types.add Puppet::Resource::Type.new(:hostclass, "")
@@ -262,12 +240,6 @@ describe Puppet::Parser::Compiler do
       @compiler.catalog.edge?(stage, klass).should be_true
     end
 
-    it "should evaluate any node classes" do
-      @node.stubs(:classes).returns(%w{one two three four})
-      @compiler.expects(:evaluate_classes).with(%w{one two three four}, @compiler.topscope)
-      @compiler.send(:evaluate_node_classes)
-    end
-
     it "should evaluate all added collections" do
       colls = []
       # And when the collections fail to evaluate.
@@ -655,7 +627,7 @@ describe Puppet::Parser::Compiler do
         catalog = @compiler.compile
 
         r2 = catalog.resources.detect {|r| r.title == 'Bar::Foo' }
-        r2.tags.should =~ ['bar::foo', 'class', 'bar', 'foo']
+        r2.tags.should == Puppet::Util::TagSet.new(['bar::foo', 'class', 'bar', 'foo'])
       end
     end
 
@@ -791,6 +763,102 @@ describe Puppet::Parser::Compiler do
     end
   end
 
+  describe "when evaluating node classes" do
+    include PuppetSpec::Compiler
+
+    describe "when provided classes in array format" do
+      let(:node) { Puppet::Node.new('someone', :classes => ['something']) }
+
+      describe "when the class exists" do
+        it "should succeed if the class is already included" do
+          manifest = <<-MANIFEST
+          class something {}
+          include something
+          MANIFEST
+
+          catalog = compile_to_catalog(manifest, node)
+
+          catalog.resource('Class', 'Something').should_not be_nil
+        end
+
+        it "should evaluate the class without parameters if it's not already included" do
+          manifest = "class something {}"
+
+          catalog = compile_to_catalog(manifest, node)
+
+          catalog.resource('Class', 'Something').should_not be_nil
+        end
+      end
+
+      it "should fail if the class doesn't exist" do
+        expect { compile_to_catalog('', node) }.to raise_error(Puppet::Error, /Could not find class something/)
+      end
+    end
+
+    describe "when provided classes in hash format" do
+      describe "for classes without parameters" do
+        let(:node) { Puppet::Node.new('someone', :classes => {'something' => {}}) }
+
+        describe "when the class exists" do
+          it "should succeed if the class is already included" do
+            manifest = <<-MANIFEST
+            class something {}
+            include something
+            MANIFEST
+
+            catalog = compile_to_catalog(manifest, node)
+
+            catalog.resource('Class', 'Something').should_not be_nil
+          end
+
+          it "should evaluate the class if it's not already included" do
+            manifest = <<-MANIFEST
+            class something {}
+            MANIFEST
+
+            catalog = compile_to_catalog(manifest, node)
+
+            catalog.resource('Class', 'Something').should_not be_nil
+          end
+        end
+
+        it "should fail if the class doesn't exist" do
+          expect { compile_to_catalog('', node) }.to raise_error(Puppet::Error, /Could not find class something/)
+        end
+      end
+
+      describe "for classes with parameters" do
+        let(:node) { Puppet::Node.new('someone', :classes => {'something' => {'configuron' => 'defrabulated'}}) }
+
+        describe "when the class exists" do
+          it "should fail if the class is already included" do
+            manifest = <<-MANIFEST
+            class something($configuron=frabulated) {}
+            include something
+            MANIFEST
+
+            expect { compile_to_catalog(manifest, node) }.to raise_error(Puppet::Error, /Class\[Something\] is already declared/)
+          end
+
+          it "should evaluate the class if it's not already included" do
+            manifest = <<-MANIFEST
+            class something($configuron=frabulated) {}
+            MANIFEST
+
+            catalog = compile_to_catalog(manifest, node)
+
+            resource = catalog.resource('Class', 'Something')
+            resource['configuron'].should == 'defrabulated'
+          end
+        end
+
+        it "should fail if the class doesn't exist" do
+          expect { compile_to_catalog('', node) }.to raise_error(Puppet::Error, /Could not find class something/)
+        end
+      end
+    end
+  end
+
   describe "when managing resource overrides" do
 
     before do
