@@ -4,7 +4,7 @@ describe 'Puppet::Parser::Functions#hiera_hash' do
   let :scope do Puppet::Parser::Scope.new_for_test_harness('foo') end
 
   it 'should require a key argument' do
-    expect { scope.function_hiera_hash([]) }.to raise_error(Puppet::ParseError)
+    expect { scope.function_hiera_hash([]) }.to raise_error(ArgumentError)
   end
 
   it 'should raise a useful error when nil is returned' do
