@@ -24,9 +24,8 @@ describe Puppet::Type.type(:package).provider(:msi) do
     MsiPackage.stubs(:installer).returns(installer)
   end
 
-  before :each do
-    # make sure we never try to execute msiexec
-    provider.expects(:execute).never
+  def expect_execute(command, status)
+    provider.expects(:execute).with(command, execute_options).returns(Puppet::Util::Execution::ProcessOutput.new('',status))
   end
 
   describe 'provider features' do
@@ -38,6 +37,7 @@ describe Puppet::Type.type(:package).provider(:msi) do
 
   describe 'on Windows', :as_platform => :windows do
     it 'should not be the default provider' do
+      # provider.expects(:execute).never
       Puppet::Type.type(:package).defaultprovider.should_not == subject.class
     end
   end
@@ -90,9 +90,7 @@ describe Puppet::Type.type(:package).provider(:msi) do
   end
 
   context '#install' do
-    before :each do
-      provider.stubs(:execute)
-    end
+    let (:command) { "msiexec.exe /qn /norestart /i #{source}" }
 
     it 'should require the source parameter' do
       resource = Puppet::Type.type(:package).new(:name => name, :provider => :msi)
@@ -104,40 +102,27 @@ describe Puppet::Type.type(:package).provider(:msi) do
 
     it 'should install using the source and install_options' do
       resource[:install_options] = { 'INSTALLDIR' => 'C:\mysql-5.1' }
-
-      provider.expects(:execute).with("msiexec.exe /qn /norestart /i #{source} INSTALLDIR=C:\\mysql-5.1", execute_options)
-      provider.expects(:exit_status).returns(0)
-
-      provider.install
-    end
-
-    it 'should warn if the package requests a reboot' do
-      provider.stubs(:exit_status).returns(194)
-
-      provider.expects(:warning).with('The package requested a reboot to finish the operation.')
+      expect_execute("#{command} INSTALLDIR=C:\\mysql-5.1", 0)
 
       provider.install
     end
 
     it 'should warn if reboot initiated' do
-      provider.stubs(:exit_status).returns(1641)
-
+      expect_execute(command, 1641)
       provider.expects(:warning).with('The package installed successfully and the system is rebooting now.')
 
       provider.install
     end
 
     it 'should warn if reboot required' do
-      provider.stubs(:exit_status).returns(3010)
-
+      expect_execute(command, 3010)
       provider.expects(:warning).with('The package installed successfully, but the system must be rebooted.')
 
       provider.install
     end
 
     it 'should fail otherwise', :if => Puppet.features.microsoft_windows? do
-      provider.stubs(:execute)
-      provider.stubs(:exit_status).returns(5)
+      expect_execute(command, 5)
 
       expect do
         provider.install
@@ -146,6 +131,9 @@ describe Puppet::Type.type(:package).provider(:msi) do
   end
 
   context '#uninstall' do
+
+    let (:command) { "msiexec.exe /qn /norestart /x #{productcode}" }
+
     before :each do
       resource[:ensure] = :absent
       provider.set(:productcode => productcode)
@@ -159,42 +147,27 @@ describe Puppet::Type.type(:package).provider(:msi) do
     end
 
     it 'should uninstall using the productcode' do
-      provider.expects(:execute).with("msiexec.exe /qn /norestart /x #{productcode}", execute_options)
-      provider.expects(:exit_status).returns(0)
-
-      provider.uninstall
-    end
-
-    it 'should warn if the package requests a reboot' do
-      provider.stubs(:execute)
-      provider.stubs(:exit_status).returns(194)
-
-      provider.expects(:warning).with('The package requested a reboot to finish the operation.')
+      expect_execute(command, 0)
 
       provider.uninstall
     end
 
     it 'should warn if reboot initiated' do
-      provider.stubs(:execute)
-      provider.stubs(:exit_status).returns(1641)
-
+      expect_execute(command, 1641)
       provider.expects(:warning).with('The package uninstalled successfully and the system is rebooting now.')
 
       provider.uninstall
     end
 
     it 'should warn if reboot required' do
-      provider.stubs(:execute)
-      provider.stubs(:exit_status).returns(3010)
-
+      expect_execute(command, 3010)
       provider.expects(:warning).with('The package uninstalled successfully, but the system must be rebooted.')
 
       provider.uninstall
     end
 
     it 'should fail otherwise', :if => Puppet.features.microsoft_windows? do
-      provider.stubs(:execute)
-      provider.stubs(:exit_status).returns(5)
+      expect_execute(command, 5)
 
       expect do
         provider.uninstall
