@@ -9,10 +9,20 @@ describe Puppet::Type.type(:service).provider(:systemd) do
     Puppet::Type.type(:service).stubs(:defaultprovider).returns described_class
     described_class.stubs(:which).with('systemctl').returns '/bin/systemctl'
   end
+  
 
   let :provider do
     described_class.new(:name => 'sshd.service')
   end
+  
+  osfamily = [ 'archlinux' ]
+
+  osfamily.each do |osfamily|
+    it "should be the default provider on #{osfamily}" do
+      Facter.expects(:value).with(:osfamily).returns(osfamily)
+      described_class.default?.should be_true
+    end
+  end  
 
   [:enabled?, :enable, :disable, :start, :stop, :status, :restart].each do |method|
     it "should have a #{method} method" do
