@@ -178,6 +178,109 @@ describe Puppet::SSL::CertificateRequest do
       end
     end
 
+    context "with custom CSR attributes" do
+
+      it "adds attributes with single values" do
+        csr_attributes = {
+          '1.3.6.1.4.1.34380.1.2.1' => 'CSR specific info',
+          '1.3.6.1.4.1.34380.1.2.2' => 'more CSR specific info',
+        }
+
+        request.generate(key, :csr_attributes => csr_attributes)
+
+        attrs = request.custom_attributes
+        attrs.should include({'oid' => '1.3.6.1.4.1.34380.1.2.1', 'value' => 'CSR specific info'})
+        attrs.should include({'oid' => '1.3.6.1.4.1.34380.1.2.2', 'value' => 'more CSR specific info'})
+      end
+
+      ['extReq', '1.2.840.113549.1.9.14'].each do |oid|
+        it "doesn't overwrite standard PKCS#9 CSR attribute '#{oid}'" do
+          expect do
+            request.generate(key, :csr_attributes => {oid => 'data'})
+          end.to raise_error ArgumentError, /Cannot specify.*#{oid}/
+        end
+      end
+
+      ['msExtReq', '1.3.6.1.4.1.311.2.1.14'].each do |oid|
+        it "doesn't overwrite Microsoft extension request OID '#{oid}'" do
+          expect do
+            request.generate(key, :csr_attributes => {oid => 'data'})
+          end.to raise_error ArgumentError, /Cannot specify.*#{oid}/
+        end
+      end
+
+      it "raises an error if an attribute cannot be created" do
+        csr_attributes = { "thats.no.moon" => "death star" }
+
+        expect do
+          request.generate(key, :csr_attributes => csr_attributes)
+        end.to raise_error Puppet::Error, /Cannot create CSR with attribute thats\.no\.moon: first num too large/
+      end
+    end
+
+    context "with extension requests" do
+      let(:extension_data) do
+        {
+          '1.3.6.1.4.1.34380.1.1.31415' => 'pi',
+          '1.3.6.1.4.1.34380.1.1.2718'  => 'e',
+        }
+      end
+
+      it "adds an extreq attribute to the CSR" do
+        request.generate(key, :extension_requests => extension_data)
+
+        exts = request.content.attributes.select { |attr| attr.oid = 'extReq' }
+        exts.length.should == 1
+      end
+
+      it "adds an extension for each entry in the extension request structure" do
+        request.generate(key, :extension_requests => extension_data)
+
+        exts = request.request_extensions
+
+        exts.should include('oid' => '1.3.6.1.4.1.34380.1.1.31415', 'value' => 'pi')
+        exts.should include('oid' => '1.3.6.1.4.1.34380.1.1.2718', 'value' => 'e')
+      end
+
+      it "defines the extensions as non-critical" do
+        request.generate(key, :extension_requests => extension_data)
+        request.request_extensions.each do |ext|
+          ext['critical'].should be_false
+        end
+      end
+
+      it "rejects the subjectAltNames extension" do
+        san_names = ['subjectAltName', '2.5.29.17']
+        san_field = 'DNS:first.tld, DNS:second.tld'
+
+        san_names.each do |name|
+          expect do
+            request.generate(key, :extension_requests => {name => san_field})
+          end.to raise_error Puppet::Error, /conflicts with internally used extension/
+        end
+      end
+
+      it "merges the extReq attribute with the subjectAltNames extension" do
+        request.generate(key,
+                         :dns_alt_names => 'first.tld, second.tld',
+                         :extension_requests => extension_data)
+        exts = request.request_extensions
+
+        exts.should include('oid' => '1.3.6.1.4.1.34380.1.1.31415', 'value' => 'pi')
+        exts.should include('oid' => '1.3.6.1.4.1.34380.1.1.2718', 'value' => 'e')
+        exts.should include('oid' => 'subjectAltName', 'value' => 'DNS:first.tld, DNS:myname, DNS:second.tld')
+
+        request.subject_alt_names.should eq ['DNS:first.tld', 'DNS:myname', 'DNS:second.tld']
+      end
+
+      it "raises an error if the OID could not be created" do
+        exts = {"thats.no.moon" => "death star"}
+        expect do
+          request.generate(key, :extension_requests => exts)
+        end.to raise_error Puppet::Error, /Cannot create CSR with extension request thats\.no\.moon: first num too large/
+      end
+    end
+
     it "should sign the csr with the provided key" do
       request.generate(key)
       request.content.verify(key.content.public_key).should be_true
