@@ -18,6 +18,10 @@ describe Puppet::Type.type(:file).attrclass(:mode) do
       expect { mode.value = '0755' }.not_to raise_error
     end
 
+    it "should accept valid symbolic strings" do
+      expect { mode.value = 'g+w,u-x' }.not_to raise_error
+    end
+
     it "should not accept strings other than octal numbers" do
       expect do
         mode.value = 'readable please!'
@@ -35,6 +39,10 @@ describe Puppet::Type.type(:file).attrclass(:mode) do
       mode.munge('0644').should == '644'
     end
 
+    it "should accept symbolic strings as arguments and return them intact" do
+      mode.munge('u=rw,go=r').should == 'u=rw,go=r'
+    end
+
     it "should accept integers are arguments" do
       mode.munge(0644).should == '644'
     end
@@ -72,11 +80,34 @@ describe Puppet::Type.type(:file).attrclass(:mode) do
       mode.must_not be_insync('755')
     end
 
-    it "should return true if the file is a link and we are managing links", :unless => Puppet.features.microsoft_windows? do
-      File.symlink('anything', path)
+    it "should return true if the file is a link and we are managing links", :if => Puppet.features.manages_symlinks? do
+      Puppet::FileSystem::File.new('anything').symlink(path)
 
       mode.must be_insync('644')
     end
+
+    describe "with a symbolic mode" do
+      let(:resource_sym) { Puppet::Type.type(:file).new :path => path, :mode => 'u+w,g-w' }
+      let(:mode_sym) { resource_sym.property(:mode) }
+
+      it "should return true if the mode matches, regardless of other bits" do
+        FileUtils.touch(path)
+
+        mode_sym.must be_insync('644')
+      end
+
+      it "should return false if the mode requires 0's where there are 1's" do
+        FileUtils.touch(path)
+
+        mode_sym.must_not be_insync('624')
+      end
+
+      it "should return false if the mode requires 1's where there are 0's" do
+        FileUtils.touch(path)
+
+        mode_sym.must_not be_insync('044')
+      end
+    end
   end
 
   describe "#retrieve" do
@@ -145,4 +176,19 @@ describe Puppet::Type.type(:file).attrclass(:mode) do
       end
     end
   end
+
+  describe "#sync with a symbolic mode" do
+    let(:resource_sym) { Puppet::Type.type(:file).new :path => path, :mode => 'u+w,g-w' }
+    let(:mode_sym) { resource_sym.property(:mode) }
+
+    before { FileUtils.touch(path) }
+
+    it "changes only the requested bits" do
+      # lower nibble must be set to 4 for the sake of passing on Windows
+      FileUtils.chmod 0464, path
+      mode_sym.sync
+      file = Puppet::FileSystem::File.new(path)
+      (file.stat.mode & 0777).to_s(8).should == "644"
+    end
+  end
 end
