@@ -62,6 +62,12 @@ describe Puppet::Type.type(:schedule) do
       end
     end
 
+    it "should not produce default schedules when default_schedules is false"  do
+      Puppet[:default_schedules] = false
+      schedules = Puppet::Type.type(:schedule).mkdefaultschedules
+      schedules.must have_exactly(0).items
+    end
+
     it "should produce a schedule named puppet with a period of hourly and a repeat of 2" do
       schedules = Puppet::Type.type(:schedule).mkdefaultschedules
       schedules.find { |s|
