@@ -20,7 +20,7 @@ describe Puppet::Util::Backups do
       file = Puppet::Type.type(:file).new(:name => path)
 
       file.expects(:bucket).never
-      FileTest.expects(:exists?).with(path).returns false
+      Puppet::FileSystem::File.expects(:exist?).with(path).returns false
 
       file.perform_backup
     end
@@ -29,23 +29,25 @@ describe Puppet::Util::Backups do
       file = Puppet::Type.type(:file).new(:name => path, :backup => false)
 
       file.expects(:bucket).never
-      FileTest.expects(:exists?).never
+      Puppet::FileSystem::File.expects(:exist?).never
 
       file.perform_backup
     end
 
     it "a bucket should be used when provided" do
-      File.stubs(:lstat).with(path).returns(mock('lstat', :ftype => 'file'))
+      stub_file = stub(path, :lstat => mock('lstat', :ftype => 'file'))
+      Puppet::FileSystem::File.expects(:new).with(path).returns stub_file
       bucket.expects(:backup).with(path).returns("mysum")
-      FileTest.expects(:exists?).with(path).returns(true)
+      Puppet::FileSystem::File.expects(:exist?).with(path).returns(true)
 
       file.perform_backup
     end
 
     it "should propagate any exceptions encountered when backing up to a filebucket" do
-      File.stubs(:lstat).with(path).returns(mock('lstat', :ftype => 'file'))
+      stub_file = stub(path, :lstat => mock('lstat', :ftype => 'file'))
+      Puppet::FileSystem::File.expects(:new).with(path).returns stub_file
       bucket.expects(:backup).raises ArgumentError
-      FileTest.expects(:exists?).with(path).returns(true)
+      Puppet::FileSystem::File.expects(:exist?).with(path).returns(true)
 
       lambda { file.perform_backup }.should raise_error(ArgumentError)
     end
@@ -56,35 +58,39 @@ describe Puppet::Util::Backups do
       let(:file) { Puppet::Type.type(:file).new(:name => path, :backup => '.'+ext) }
 
       it "should remove any local backup if one exists" do
-        File.expects(:lstat).with(backup).returns stub("stat", :ftype => "file")
-        File.expects(:unlink).with(backup)
+        stub_file = stub(backup, :lstat => stub('stat', :ftype => 'file'))
+        Puppet::FileSystem::File.expects(:new).with(backup).returns stub_file
+        Puppet::FileSystem::File.expects(:unlink).with(backup)
         FileUtils.stubs(:cp_r)
-        FileTest.expects(:exists?).with(path).returns(true)
+        Puppet::FileSystem::File.expects(:exist?).with(path).returns(true)
 
         file.perform_backup
       end
 
       it "should fail when the old backup can't be removed" do
-        File.expects(:lstat).with(backup).returns stub("stat", :ftype => "file")
-        File.expects(:unlink).with(backup).raises ArgumentError
+        stub_file = stub(backup, :lstat => stub('stat', :ftype => 'file'))
+        Puppet::FileSystem::File.expects(:new).with(backup).returns stub_file
+        Puppet::FileSystem::File.expects(:unlink).with(backup).raises ArgumentError
         FileUtils.expects(:cp_r).never
-        FileTest.expects(:exists?).with(path).returns(true)
+        Puppet::FileSystem::File.expects(:exist?).with(path).returns(true)
 
         lambda { file.perform_backup }.should raise_error(Puppet::Error)
       end
 
       it "should not try to remove backups that don't exist" do
-        File.expects(:lstat).with(backup).raises(Errno::ENOENT)
-        File.expects(:unlink).with(backup).never
+        stub_file = stub(backup)
+        Puppet::FileSystem::File.expects(:new).with(backup).returns stub_file
+        stub_file.expects(:lstat).raises(Errno::ENOENT)
+        Puppet::FileSystem::File.expects(:unlink).with(backup).never
         FileUtils.stubs(:cp_r)
-        FileTest.expects(:exists?).with(path).returns(true)
+        Puppet::FileSystem::File.expects(:exist?).with(path).returns(true)
 
         file.perform_backup
       end
 
       it "a copy should be created in the local directory" do
         FileUtils.expects(:cp_r).with(path, backup, :preserve => true)
-        FileTest.stubs(:exists?).with(path).returns(true)
+        Puppet::FileSystem::File.stubs(:exist?).with(path).returns(true)
 
         file.perform_backup.should be_true
       end
@@ -92,7 +98,7 @@ describe Puppet::Util::Backups do
       it "should propagate exceptions if no backup can be created" do
         FileUtils.expects(:cp_r).raises ArgumentError
 
-        FileTest.stubs(:exists?).with(path).returns(true)
+        Puppet::FileSystem::File.stubs(:exist?).with(path).returns(true)
         lambda { file.perform_backup }.should raise_error(Puppet::Error)
       end
     end
@@ -108,10 +114,11 @@ describe Puppet::Util::Backups do
 
       bucket.expects(:backup).with(filename).returns true
 
-      File.stubs(:lstat).with(path).returns(stub('lstat', :ftype => 'directory'))
+      stub_file = stub(path, :lstat => stub('stat', :ftype => 'directory'))
+      Puppet::FileSystem::File.expects(:new).with(path).returns stub_file
 
-      FileTest.stubs(:exists?).with(path).returns(true)
-      FileTest.stubs(:exists?).with(filename).returns(true)
+      Puppet::FileSystem::File.stubs(:exist?).with(path).returns(true)
+      Puppet::FileSystem::File.stubs(:exist?).with(filename).returns(true)
 
       file.perform_backup
     end
@@ -120,7 +127,8 @@ describe Puppet::Util::Backups do
       file = Puppet::Type.type(:file).new(:name => path, :backup => 'foo', :recurse => true)
 
       bucket.expects(:backup).never
-      File.stubs(:stat).with(path).returns(stub('stat', :ftype => 'directory'))
+      stub_file = stub('file', :stat => stub('stat', :ftype => 'directory'))
+      Puppet::FileSystem::File.stubs(:new).with(path).returns stub_file
       Find.expects(:find).never
 
       file.perform_backup
