@@ -5,15 +5,7 @@ require 'puppet/util/rdoc'
 require 'rdoc/rdoc'
 
 describe Puppet::Util::RDoc do
-  it "should fail with a clear error without RDoc 1.*" do
-    Puppet.features.stubs(:rdoc1?).returns(false)
-
-    expect {
-      Puppet::Util::RDoc.rdoc("output", [])
-    }.to raise_error(/the version of RDoc .* is not supported/)
-  end
-
-  describe "when generating RDoc HTML documentation", :if => Puppet.features.rdoc1? do
+  describe "when generating RDoc HTML documentation" do
     before :each do
       @rdoc = stub_everything 'rdoc'
       RDoc::RDoc.stubs(:new).returns(@rdoc)
@@ -24,12 +16,6 @@ describe Puppet::Util::RDoc do
       Puppet::Util::RDoc.rdoc("output", [])
     end
 
-    it "should install the Puppet HTML Generator into RDoc generators" do
-      Puppet::Util::RDoc.rdoc("output", [])
-
-      RDoc::RDoc::GENERATORS["puppet"].file_name.should == "puppet/util/rdoc/generators/puppet_generator.rb"
-    end
-
     it "should tell RDoc to generate documentation using the Puppet generator" do
       @rdoc.expects(:document).with { |args| args.include?("--fmt") and args.include?("puppet") }
 
@@ -48,18 +34,26 @@ describe Puppet::Util::RDoc do
       Puppet::Util::RDoc.rdoc("output", [], "utf-8")
     end
 
-    it "should tell RDoc to force updates of indices when RDoc supports it" do
-      Options::OptionList.stubs(:options).returns([["--force-update", "-U", 0 ]])
-      @rdoc.expects(:document).with { |args| args.include?("--force-update") }
+    describe "with rdoc1", :if => Puppet.features.rdoc1? do
+      it "should install the Puppet HTML Generator into RDoc generators" do
+        Puppet::Util::RDoc.rdoc("output", [])
 
-      Puppet::Util::RDoc.rdoc("output", [])
-    end
+        RDoc::RDoc::GENERATORS["puppet"].file_name.should == "puppet/util/rdoc/generators/puppet_generator.rb"
+      end
 
-    it "should not tell RDoc to force updates of indices when RDoc doesn't support it" do
-      Options::OptionList.stubs(:options).returns([])
-      @rdoc.expects(:document).never.with { |args| args.include?("--force-update") }
+      it "should tell RDoc to force updates of indices when RDoc supports it" do
+        ::Options::OptionList.stubs(:options).returns([["--force-update", "-U", 0 ]])
+        @rdoc.expects(:document).with { |args| args.include?("--force-update") }
 
-      Puppet::Util::RDoc.rdoc("output", [])
+        Puppet::Util::RDoc.rdoc("output", [])
+      end
+
+      it "should not tell RDoc to force updates of indices when RDoc doesn't support it" do
+        ::Options::OptionList.stubs(:options).returns([])
+        @rdoc.expects(:document).never.with { |args| args.include?("--force-update") }
+
+        Puppet::Util::RDoc.rdoc("output", [])
+      end
     end
 
     it "should tell RDoc to use the given outputdir" do
