@@ -77,7 +77,7 @@ describe Puppet::Util::Storage do
       end
 
       it "should not fail to load" do
-        FileTest.exists?(@path).should be_false
+        Puppet::FileSystem::File.exist?(@path).should be_false
         Puppet[:statedir] = @path
         Puppet::Util::Storage.load
         Puppet[:statefile] = @path
@@ -85,7 +85,7 @@ describe Puppet::Util::Storage do
       end
 
       it "should not lose its internal state when load() is called" do
-        FileTest.exists?(@path).should be_false
+        Puppet::FileSystem::File.exist?(@path).should be_false
 
         Puppet::Util::Storage.cache(:yayness)
         Puppet::Util::Storage.state.should == {:yayness=>{}}
@@ -176,12 +176,12 @@ describe Puppet::Util::Storage do
     end
 
     it "should create the state file if it does not exist" do
-      FileTest.exists?(Puppet[:statefile]).should be_false
+      Puppet::FileSystem::File.exist?(Puppet[:statefile]).should be_false
       Puppet::Util::Storage.cache(:yayness)
 
       Puppet::Util::Storage.store
 
-      FileTest.exists?(Puppet[:statefile]).should be_true
+      Puppet::FileSystem::File.exist?(Puppet[:statefile]).should be_true
     end
 
     it "should raise an exception if the state file is not a regular file" do
